@@ -1,8 +1,7 @@
 #![allow(unused_variables, non_upper_case_globals, non_snake_case, unused_unsafe, non_camel_case_types, dead_code, clippy::all)]
 #[cfg(feature = "Graphics_DirectX_Direct3D11")]
 pub mod Direct3D11;
-#[doc = "*Required features: `Graphics_DirectX`*"]
-#[derive(:: std :: cmp :: PartialEq, :: std :: cmp :: Eq, :: std :: marker :: Copy, :: std :: clone :: Clone, :: std :: default :: Default, :: std :: fmt :: Debug)]
+#[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq, :: core :: marker :: Copy, :: core :: clone :: Clone, :: core :: default :: Default, :: core :: fmt :: Debug)]
 #[repr(transparent)]
 pub struct DirectXAlphaMode(pub i32);
 impl DirectXAlphaMode {
@@ -11,22 +10,21 @@ impl DirectXAlphaMode {
     pub const Straight: DirectXAlphaMode = DirectXAlphaMode(2i32);
     pub const Ignore: DirectXAlphaMode = DirectXAlphaMode(3i32);
 }
-impl ::std::convert::From<i32> for DirectXAlphaMode {
+impl ::core::convert::From<i32> for DirectXAlphaMode {
     fn from(value: i32) -> Self {
         Self(value)
     }
 }
-unsafe impl ::windows::runtime::Abi for DirectXAlphaMode {
+unsafe impl ::windows::core::Abi for DirectXAlphaMode {
     type Abi = Self;
 }
-unsafe impl ::windows::runtime::RuntimeType for DirectXAlphaMode {
-    const SIGNATURE: ::windows::runtime::ConstBuffer = ::windows::runtime::ConstBuffer::from_slice(b"enum(Windows.Graphics.DirectX.DirectXAlphaMode;i4)");
+unsafe impl ::windows::core::RuntimeType for DirectXAlphaMode {
+    const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"enum(Windows.Graphics.DirectX.DirectXAlphaMode;i4)");
 }
-impl ::windows::runtime::DefaultType for DirectXAlphaMode {
+impl ::windows::core::DefaultType for DirectXAlphaMode {
     type DefaultType = Self;
 }
-#[doc = "*Required features: `Graphics_DirectX`*"]
-#[derive(:: std :: cmp :: PartialEq, :: std :: cmp :: Eq, :: std :: marker :: Copy, :: std :: clone :: Clone, :: std :: default :: Default, :: std :: fmt :: Debug)]
+#[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq, :: core :: marker :: Copy, :: core :: clone :: Clone, :: core :: default :: Default, :: core :: fmt :: Debug)]
 #[repr(transparent)]
 pub struct DirectXColorSpace(pub i32);
 impl DirectXColorSpace {
@@ -56,22 +54,21 @@ impl DirectXColorSpace {
     pub const YccStudioG24LeftP2020: DirectXColorSpace = DirectXColorSpace(23i32);
     pub const YccStudioG24TopLeftP2020: DirectXColorSpace = DirectXColorSpace(24i32);
 }
-impl ::std::convert::From<i32> for DirectXColorSpace {
+impl ::core::convert::From<i32> for DirectXColorSpace {
     fn from(value: i32) -> Self {
         Self(value)
     }
 }
-unsafe impl ::windows::runtime::Abi for DirectXColorSpace {
+unsafe impl ::windows::core::Abi for DirectXColorSpace {
     type Abi = Self;
 }
-unsafe impl ::windows::runtime::RuntimeType for DirectXColorSpace {
-    const SIGNATURE: ::windows::runtime::ConstBuffer = ::windows::runtime::ConstBuffer::from_slice(b"enum(Windows.Graphics.DirectX.DirectXColorSpace;i4)");
+unsafe impl ::windows::core::RuntimeType for DirectXColorSpace {
+    const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"enum(Windows.Graphics.DirectX.DirectXColorSpace;i4)");
 }
-impl ::windows::runtime::DefaultType for DirectXColorSpace {
+impl ::windows::core::DefaultType for DirectXColorSpace {
     type DefaultType = Self;
 }
-#[doc = "*Required features: `Graphics_DirectX`*"]
-#[derive(:: std :: cmp :: PartialEq, :: std :: cmp :: Eq, :: std :: marker :: Copy, :: std :: clone :: Clone, :: std :: default :: Default, :: std :: fmt :: Debug)]
+#[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq, :: core :: marker :: Copy, :: core :: clone :: Clone, :: core :: default :: Default, :: core :: fmt :: Debug)]
 #[repr(transparent)]
 pub struct DirectXPixelFormat(pub i32);
 impl DirectXPixelFormat {
@@ -197,22 +194,21 @@ impl DirectXPixelFormat {
     pub const SamplerFeedbackMinMipOpaque: DirectXPixelFormat = DirectXPixelFormat(189i32);
     pub const SamplerFeedbackMipRegionUsedOpaque: DirectXPixelFormat = DirectXPixelFormat(190i32);
 }
-impl ::std::convert::From<i32> for DirectXPixelFormat {
+impl ::core::convert::From<i32> for DirectXPixelFormat {
     fn from(value: i32) -> Self {
         Self(value)
     }
 }
-unsafe impl ::windows::runtime::Abi for DirectXPixelFormat {
+unsafe impl ::windows::core::Abi for DirectXPixelFormat {
     type Abi = Self;
 }
-unsafe impl ::windows::runtime::RuntimeType for DirectXPixelFormat {
-    const SIGNATURE: ::windows::runtime::ConstBuffer = ::windows::runtime::ConstBuffer::from_slice(b"enum(Windows.Graphics.DirectX.DirectXPixelFormat;i4)");
+unsafe impl ::windows::core::RuntimeType for DirectXPixelFormat {
+    const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"enum(Windows.Graphics.DirectX.DirectXPixelFormat;i4)");
 }
-impl ::windows::runtime::DefaultType for DirectXPixelFormat {
+impl ::windows::core::DefaultType for DirectXPixelFormat {
     type DefaultType = Self;
 }
-#[doc = "*Required features: `Graphics_DirectX`*"]
-#[derive(:: std :: cmp :: PartialEq, :: std :: cmp :: Eq, :: std :: marker :: Copy, :: std :: clone :: Clone, :: std :: default :: Default, :: std :: fmt :: Debug)]
+#[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq, :: core :: marker :: Copy, :: core :: clone :: Clone, :: core :: default :: Default, :: core :: fmt :: Debug)]
 #[repr(transparent)]
 pub struct DirectXPrimitiveTopology(pub i32);
 impl DirectXPrimitiveTopology {
@@ -223,17 +219,17 @@ impl DirectXPrimitiveTopology {
     pub const TriangleList: DirectXPrimitiveTopology = DirectXPrimitiveTopology(4i32);
     pub const TriangleStrip: DirectXPrimitiveTopology = DirectXPrimitiveTopology(5i32);
 }
-impl ::std::convert::From<i32> for DirectXPrimitiveTopology {
+impl ::core::convert::From<i32> for DirectXPrimitiveTopology {
     fn from(value: i32) -> Self {
         Self(value)
     }
 }
-unsafe impl ::windows::runtime::Abi for DirectXPrimitiveTopology {
+unsafe impl ::windows::core::Abi for DirectXPrimitiveTopology {
     type Abi = Self;
 }
-unsafe impl ::windows::runtime::RuntimeType for DirectXPrimitiveTopology {
-    const SIGNATURE: ::windows::runtime::ConstBuffer = ::windows::runtime::ConstBuffer::from_slice(b"enum(Windows.Graphics.DirectX.DirectXPrimitiveTopology;i4)");
+unsafe impl ::windows::core::RuntimeType for DirectXPrimitiveTopology {
+    const SIGNATURE: ::windows::core::ConstBuffer = ::windows::core::ConstBuffer::from_slice(b"enum(Windows.Graphics.DirectX.DirectXPrimitiveTopology;i4)");
 }
-impl ::windows::runtime::DefaultType for DirectXPrimitiveTopology {
+impl ::windows::core::DefaultType for DirectXPrimitiveTopology {
     type DefaultType = Self;
 }
