@@ -19,6 +19,3 @@ pub mod StartScreen;
 pub mod System;
 #[cfg(feature = "Phone_UI")]
 pub mod UI;
-#[repr(C)]
-#[derive(:: std :: clone :: Clone, :: std :: default :: Default, :: std :: fmt :: Debug, :: std :: cmp :: PartialEq, :: std :: cmp :: Eq, :: std :: marker :: Copy)]
-pub struct PhoneContract(pub u8);
