@@ -1,143 +1,138 @@
 #![allow(unused_variables, non_upper_case_globals, non_snake_case, unused_unsafe, non_camel_case_types, dead_code, clippy::all)]
-#[derive(:: std :: clone :: Clone, :: std :: marker :: Copy)]
+#[derive(:: core :: clone :: Clone, :: core :: marker :: Copy)]
 #[repr(C)]
-#[doc = "*Required features: `Win32_Storage_OperationRecorder`*"]
 pub struct OPERATION_END_PARAMETERS {
     pub Version: u32,
     pub OperationId: u32,
     pub Flags: OPERATION_END_PARAMETERS_FLAGS,
 }
 impl OPERATION_END_PARAMETERS {}
-impl ::std::default::Default for OPERATION_END_PARAMETERS {
+impl ::core::default::Default for OPERATION_END_PARAMETERS {
     fn default() -> Self {
-        unsafe { ::std::mem::zeroed() }
+        unsafe { ::core::mem::zeroed() }
     }
 }
-impl ::std::fmt::Debug for OPERATION_END_PARAMETERS {
-    fn fmt(&self, fmt: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
+impl ::core::fmt::Debug for OPERATION_END_PARAMETERS {
+    fn fmt(&self, fmt: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
         fmt.debug_struct("OPERATION_END_PARAMETERS").field("Version", &self.Version).field("OperationId", &self.OperationId).field("Flags", &self.Flags).finish()
     }
 }
-impl ::std::cmp::PartialEq for OPERATION_END_PARAMETERS {
+impl ::core::cmp::PartialEq for OPERATION_END_PARAMETERS {
     fn eq(&self, other: &Self) -> bool {
         self.Version == other.Version && self.OperationId == other.OperationId && self.Flags == other.Flags
     }
 }
-impl ::std::cmp::Eq for OPERATION_END_PARAMETERS {}
-unsafe impl ::windows::runtime::Abi for OPERATION_END_PARAMETERS {
+impl ::core::cmp::Eq for OPERATION_END_PARAMETERS {}
+unsafe impl ::windows::core::Abi for OPERATION_END_PARAMETERS {
     type Abi = Self;
 }
-#[doc = "*Required features: `Win32_Storage_OperationRecorder`*"]
-#[derive(:: std :: cmp :: PartialEq, :: std :: cmp :: Eq, :: std :: marker :: Copy, :: std :: clone :: Clone, :: std :: default :: Default, :: std :: fmt :: Debug)]
+#[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq, :: core :: marker :: Copy, :: core :: clone :: Clone, :: core :: default :: Default, :: core :: fmt :: Debug)]
 #[repr(transparent)]
 pub struct OPERATION_END_PARAMETERS_FLAGS(pub u32);
 pub const OPERATION_END_DISCARD: OPERATION_END_PARAMETERS_FLAGS = OPERATION_END_PARAMETERS_FLAGS(1u32);
-impl ::std::convert::From<u32> for OPERATION_END_PARAMETERS_FLAGS {
+impl ::core::convert::From<u32> for OPERATION_END_PARAMETERS_FLAGS {
     fn from(value: u32) -> Self {
         Self(value)
     }
 }
-unsafe impl ::windows::runtime::Abi for OPERATION_END_PARAMETERS_FLAGS {
+unsafe impl ::windows::core::Abi for OPERATION_END_PARAMETERS_FLAGS {
     type Abi = Self;
 }
-impl ::std::ops::BitOr for OPERATION_END_PARAMETERS_FLAGS {
+impl ::core::ops::BitOr for OPERATION_END_PARAMETERS_FLAGS {
     type Output = Self;
     fn bitor(self, rhs: Self) -> Self {
         Self(self.0 | rhs.0)
     }
 }
-impl ::std::ops::BitAnd for OPERATION_END_PARAMETERS_FLAGS {
+impl ::core::ops::BitAnd for OPERATION_END_PARAMETERS_FLAGS {
     type Output = Self;
     fn bitand(self, rhs: Self) -> Self {
         Self(self.0 & rhs.0)
     }
 }
-impl ::std::ops::BitOrAssign for OPERATION_END_PARAMETERS_FLAGS {
+impl ::core::ops::BitOrAssign for OPERATION_END_PARAMETERS_FLAGS {
     fn bitor_assign(&mut self, rhs: Self) {
         self.0.bitor_assign(rhs.0)
     }
 }
-impl ::std::ops::BitAndAssign for OPERATION_END_PARAMETERS_FLAGS {
+impl ::core::ops::BitAndAssign for OPERATION_END_PARAMETERS_FLAGS {
     fn bitand_assign(&mut self, rhs: Self) {
         self.0.bitand_assign(rhs.0)
     }
 }
-impl ::std::ops::Not for OPERATION_END_PARAMETERS_FLAGS {
+impl ::core::ops::Not for OPERATION_END_PARAMETERS_FLAGS {
     type Output = Self;
     fn not(self) -> Self {
         Self(self.0.not())
     }
 }
-#[doc = "*Required features: `Win32_Storage_OperationRecorder`*"]
-#[derive(:: std :: cmp :: PartialEq, :: std :: cmp :: Eq, :: std :: marker :: Copy, :: std :: clone :: Clone, :: std :: default :: Default, :: std :: fmt :: Debug)]
+#[derive(:: core :: cmp :: PartialEq, :: core :: cmp :: Eq, :: core :: marker :: Copy, :: core :: clone :: Clone, :: core :: default :: Default, :: core :: fmt :: Debug)]
 #[repr(transparent)]
 pub struct OPERATION_START_FLAGS(pub u32);
 pub const OPERATION_START_TRACE_CURRENT_THREAD: OPERATION_START_FLAGS = OPERATION_START_FLAGS(1u32);
-impl ::std::convert::From<u32> for OPERATION_START_FLAGS {
+impl ::core::convert::From<u32> for OPERATION_START_FLAGS {
     fn from(value: u32) -> Self {
         Self(value)
     }
 }
-unsafe impl ::windows::runtime::Abi for OPERATION_START_FLAGS {
+unsafe impl ::windows::core::Abi for OPERATION_START_FLAGS {
     type Abi = Self;
 }
-impl ::std::ops::BitOr for OPERATION_START_FLAGS {
+impl ::core::ops::BitOr for OPERATION_START_FLAGS {
     type Output = Self;
     fn bitor(self, rhs: Self) -> Self {
         Self(self.0 | rhs.0)
     }
 }
-impl ::std::ops::BitAnd for OPERATION_START_FLAGS {
+impl ::core::ops::BitAnd for OPERATION_START_FLAGS {
     type Output = Self;
     fn bitand(self, rhs: Self) -> Self {
         Self(self.0 & rhs.0)
     }
 }
-impl ::std::ops::BitOrAssign for OPERATION_START_FLAGS {
+impl ::core::ops::BitOrAssign for OPERATION_START_FLAGS {
     fn bitor_assign(&mut self, rhs: Self) {
         self.0.bitor_assign(rhs.0)
     }
 }
-impl ::std::ops::BitAndAssign for OPERATION_START_FLAGS {
+impl ::core::ops::BitAndAssign for OPERATION_START_FLAGS {
     fn bitand_assign(&mut self, rhs: Self) {
         self.0.bitand_assign(rhs.0)
     }
 }
-impl ::std::ops::Not for OPERATION_START_FLAGS {
+impl ::core::ops::Not for OPERATION_START_FLAGS {
     type Output = Self;
     fn not(self) -> Self {
         Self(self.0.not())
     }
 }
-#[derive(:: std :: clone :: Clone, :: std :: marker :: Copy)]
+#[derive(:: core :: clone :: Clone, :: core :: marker :: Copy)]
 #[repr(C)]
-#[doc = "*Required features: `Win32_Storage_OperationRecorder`*"]
 pub struct OPERATION_START_PARAMETERS {
     pub Version: u32,
     pub OperationId: u32,
     pub Flags: OPERATION_START_FLAGS,
 }
 impl OPERATION_START_PARAMETERS {}
-impl ::std::default::Default for OPERATION_START_PARAMETERS {
+impl ::core::default::Default for OPERATION_START_PARAMETERS {
     fn default() -> Self {
-        unsafe { ::std::mem::zeroed() }
+        unsafe { ::core::mem::zeroed() }
     }
 }
-impl ::std::fmt::Debug for OPERATION_START_PARAMETERS {
-    fn fmt(&self, fmt: &mut ::std::fmt::Formatter<'_>) -> ::std::fmt::Result {
+impl ::core::fmt::Debug for OPERATION_START_PARAMETERS {
+    fn fmt(&self, fmt: &mut ::core::fmt::Formatter<'_>) -> ::core::fmt::Result {
         fmt.debug_struct("OPERATION_START_PARAMETERS").field("Version", &self.Version).field("OperationId", &self.OperationId).field("Flags", &self.Flags).finish()
     }
 }
-impl ::std::cmp::PartialEq for OPERATION_START_PARAMETERS {
+impl ::core::cmp::PartialEq for OPERATION_START_PARAMETERS {
     fn eq(&self, other: &Self) -> bool {
         self.Version == other.Version && self.OperationId == other.OperationId && self.Flags == other.Flags
     }
 }
-impl ::std::cmp::Eq for OPERATION_START_PARAMETERS {}
-unsafe impl ::windows::runtime::Abi for OPERATION_START_PARAMETERS {
+impl ::core::cmp::Eq for OPERATION_START_PARAMETERS {}
+unsafe impl ::windows::core::Abi for OPERATION_START_PARAMETERS {
     type Abi = Self;
 }
-#[doc = "*Required features: `Win32_Storage_OperationRecorder`, `Win32_Foundation`*"]
 #[cfg(feature = "Win32_Foundation")]
 #[inline]
 pub unsafe fn OperationEnd(operationendparams: *const OPERATION_END_PARAMETERS) -> super::super::Foundation::BOOL {
@@ -147,12 +142,11 @@ pub unsafe fn OperationEnd(operationendparams: *const OPERATION_END_PARAMETERS)
         extern "system" {
             fn OperationEnd(operationendparams: *const OPERATION_END_PARAMETERS) -> super::super::Foundation::BOOL;
         }
-        ::std::mem::transmute(OperationEnd(::std::mem::transmute(operationendparams)))
+        ::core::mem::transmute(OperationEnd(::core::mem::transmute(operationendparams)))
     }
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
 }
-#[doc = "*Required features: `Win32_Storage_OperationRecorder`, `Win32_Foundation`*"]
 #[cfg(feature = "Win32_Foundation")]
 #[inline]
 pub unsafe fn OperationStart(operationstartparams: *const OPERATION_START_PARAMETERS) -> super::super::Foundation::BOOL {
@@ -162,7 +156,7 @@ pub unsafe fn OperationStart(operationstartparams: *const OPERATION_START_PARAME
         extern "system" {
             fn OperationStart(operationstartparams: *const OPERATION_START_PARAMETERS) -> super::super::Foundation::BOOL;
         }
-        ::std::mem::transmute(OperationStart(::std::mem::transmute(operationstartparams)))
+        ::core::mem::transmute(OperationStart(::core::mem::transmute(operationstartparams)))
     }
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
