@@ -1,5 +1,4 @@
 #![allow(unused_variables, non_upper_case_globals, non_snake_case, unused_unsafe, non_camel_case_types, dead_code, clippy::all)]
-#[doc = "*Required features: `Win32_System_Diagnostics_Ceip`, `Win32_Foundation`*"]
 #[cfg(feature = "Win32_Foundation")]
 #[inline]
 pub unsafe fn CeipIsOptedIn() -> super::super::super::Foundation::BOOL {
@@ -9,7 +8,7 @@ pub unsafe fn CeipIsOptedIn() -> super::super::super::Foundation::BOOL {
         extern "system" {
             fn CeipIsOptedIn() -> super::super::super::Foundation::BOOL;
         }
-        ::std::mem::transmute(CeipIsOptedIn())
+        ::core::mem::transmute(CeipIsOptedIn())
     }
     #[cfg(not(windows))]
     unimplemented!("Unsupported target OS");
